@@ -14,5 +14,5 @@ class Config:
     stationary_label: str = "stationary"
     npz_filename: str = "landmarks.npz"
     seq_length: int = 60
-    num_features: int = 14
+    num_original_features: int = 16
     weights_filename: str = f"hgd_weights_v{__weights_version__}.h5"
